==> jc-1.4.0.tar.gz: java/lang/SecurityException.h <==
// public class java.lang.SecurityException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 767fc1626c63609e java_lang_SecurityException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_java_lang_SecurityException_H_
#define _JC_java_lang_SecurityException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_SecurityException$sub_refs	_jc_java_lang_SecurityException$sub_refs;
typedef struct _jc_java_lang_SecurityException$sub_nonrefs	_jc_java_lang_SecurityException$sub_nonrefs;
typedef struct _jc_java_lang_SecurityException$refs	_jc_java_lang_SecurityException$refs;
typedef struct _jc_java_lang_SecurityException$nonrefs	_jc_java_lang_SecurityException$nonrefs;
typedef struct _jc_java_lang_SecurityException$object	_jc_java_lang_SecurityException$object;

typedef struct _jc_java_lang_SecurityException$fields_struct	_jc_java_lang_SecurityException$fields_struct;
typedef const struct _jc_java_lang_SecurityException$vmethods	_jc_java_lang_SecurityException$vmethods;
typedef const struct _jc_java_lang_SecurityException$vtable	_jc_java_lang_SecurityException$vtable;
typedef const struct _jc_java_lang_SecurityException$vtype	_jc_java_lang_SecurityException$vtype;

// Class fields structure
struct _jc_java_lang_SecurityException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_SecurityException$fields_struct _jc_java_lang_SecurityException$class_fields;

// Constructors
extern void _jc_java_lang_SecurityException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_SecurityException$object *);
extern void _jc_java_lang_SecurityException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_SecurityException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_lang_SecurityException$vmethods {
};

// Vtable
struct _jc_java_lang_SecurityException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_lang_SecurityException$vmethods	java_lang_SecurityException;
};

// Vtype
struct _jc_java_lang_SecurityException$vtype {
	_jc_type			type;
	_jc_java_lang_SecurityException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_SecurityException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_SecurityException$refs {
    _jc_java_lang_SecurityException$sub_refs	java_lang_SecurityException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_SecurityException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_SecurityException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_lang_SecurityException$sub_nonrefs	java_lang_SecurityException;
};

// Object instance structure
struct _jc_java_lang_SecurityException$object {
	_jc_java_lang_SecurityException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_SecurityException$vtype	*vtype;
	_jc_java_lang_SecurityException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_SecurityException$vtype _jc_java_lang_SecurityException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_SecurityException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_SecurityException$class_object;

#endif	/* _JC_java_lang_SecurityException_H_ */

==> jc-1.4.6.tar.gz: java/lang/SecurityException.h <==
// public class java.lang.SecurityException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 767fc1626c63609e java_lang_SecurityException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_java_lang_SecurityException_H_
#define _JC_java_lang_SecurityException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_SecurityException$sub_refs	_jc_java_lang_SecurityException$sub_refs;
typedef struct _jc_java_lang_SecurityException$sub_nonrefs	_jc_java_lang_SecurityException$sub_nonrefs;
typedef struct _jc_java_lang_SecurityException$refs	_jc_java_lang_SecurityException$refs;
typedef struct _jc_java_lang_SecurityException$nonrefs	_jc_java_lang_SecurityException$nonrefs;
typedef struct _jc_java_lang_SecurityException$object	_jc_java_lang_SecurityException$object;

typedef struct _jc_java_lang_SecurityException$fields_struct	_jc_java_lang_SecurityException$fields_struct;
typedef const struct _jc_java_lang_SecurityException$vmethods	_jc_java_lang_SecurityException$vmethods;
typedef const struct _jc_java_lang_SecurityException$vtable	_jc_java_lang_SecurityException$vtable;
typedef const struct _jc_java_lang_SecurityException$vtype	_jc_java_lang_SecurityException$vtype;

// Class fields structure
struct _jc_java_lang_SecurityException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_SecurityException$fields_struct _jc_java_lang_SecurityException$class_fields;

// Constructors
extern void _jc_java_lang_SecurityException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_SecurityException$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_SecurityException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_SecurityException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_lang_SecurityException$vmethods {
};

// Vtable
struct _jc_java_lang_SecurityException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_lang_SecurityException$vmethods	java_lang_SecurityException;
};

// Vtype
struct _jc_java_lang_SecurityException$vtype {
	_jc_type			type;
	_jc_java_lang_SecurityException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_SecurityException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_SecurityException$refs {
    _jc_java_lang_SecurityException$sub_refs	java_lang_SecurityException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_SecurityException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_SecurityException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_lang_SecurityException$sub_nonrefs	java_lang_SecurityException;
};

// Object instance structure
struct _jc_java_lang_SecurityException$object {
	_jc_java_lang_SecurityException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_SecurityException$vtype	*vtype;
	_jc_java_lang_SecurityException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_SecurityException$vtype _jc_java_lang_SecurityException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_SecurityException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_SecurityException$class_object;

#endif	/* _JC_java_lang_SecurityException_H_ */
